@@ -384,13 +384,13 @@ class CfnApplication(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The Arn for the application.
@@ -399,7 +399,7 @@ class CfnApplication(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         '''The application Id in the respective resource.
@@ -408,12 +408,12 @@ class CfnApplication(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.core.TagManager:
         '''Key-value pairs you can use to associate with the application.
@@ -422,7 +422,7 @@ class CfnApplication(
         '''
         return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''The name of the application.
@@ -440,7 +440,7 @@ class CfnApplication(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
         '''The description of the application.
@@ -637,13 +637,13 @@ class CfnAttributeGroup(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The Arn for the attribute group.
@@ -652,7 +652,7 @@ class CfnAttributeGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         '''The attribute group Id in the respective resource.
@@ -661,12 +661,12 @@ class CfnAttributeGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.core.TagManager:
         '''Key-value pairs you can use to associate with the attribute group.
@@ -675,7 +675,7 @@ class CfnAttributeGroup(
         '''
         return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributes")
     def attributes(self) -> typing.Any:
         '''A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
@@ -691,7 +691,7 @@ class CfnAttributeGroup(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributes", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''The name of the attribute group.
@@ -707,7 +707,7 @@ class CfnAttributeGroup(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
         '''The description of the attribute group that the user provides.
@@ -799,13 +799,13 @@ class CfnAttributeGroupAssociation(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrApplicationArn")
     def attr_application_arn(self) -> builtins.str:
         '''
@@ -813,7 +813,7 @@ class CfnAttributeGroupAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrApplicationArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrAttributeGroupArn")
     def attr_attribute_group_arn(self) -> builtins.str:
         '''
@@ -821,7 +821,7 @@ class CfnAttributeGroupAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrAttributeGroupArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         '''The Id of the Association.
@@ -830,12 +830,12 @@ class CfnAttributeGroupAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="application")
     def application(self) -> builtins.str:
         '''The name or ID of the application.
@@ -851,7 +851,7 @@ class CfnAttributeGroupAssociation(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroup")
     def attribute_group(self) -> builtins.str:
         '''The name or ID of the attribute group that holds the attributes to describe the application.
@@ -1131,13 +1131,13 @@ class CfnResourceAssociation(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrApplicationArn")
     def attr_application_arn(self) -> builtins.str:
         '''
@@ -1145,7 +1145,7 @@ class CfnResourceAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrApplicationArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         '''The Id of the Association.
@@ -1154,7 +1154,7 @@ class CfnResourceAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrResourceArn")
     def attr_resource_arn(self) -> builtins.str:
         '''
@@ -1162,12 +1162,12 @@ class CfnResourceAssociation(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrResourceArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="application")
     def application(self) -> builtins.str:
         '''The name or ID of the application.
@@ -1183,7 +1183,7 @@ class CfnResourceAssociation(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="resource")
     def resource(self) -> builtins.str:
         '''The name or ID of the resource of which the application will be associated.
@@ -1199,7 +1199,7 @@ class CfnResourceAssociation(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="resourceType")
     def resource_type(self) -> builtins.str:
         '''The type of resource of which the application will be associated.
@@ -1318,7 +1318,7 @@ class IApplication(aws_cdk.core.IResource, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationArn")
     def application_arn(self) -> builtins.str:
         '''(experimental) The ARN of the application.
@@ -1328,7 +1328,7 @@ class IApplication(aws_cdk.core.IResource, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationId")
     def application_id(self) -> builtins.str:
         '''(experimental) The ID of the application.
@@ -1360,7 +1360,7 @@ class IApplication(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IApplicationProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''(experimental) A Service Catalog AppRegistry Application.
 
@@ -1369,7 +1369,7 @@ class _IApplicationProxy(
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-servicecatalogappregistry.IApplication"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationArn")
     def application_arn(self) -> builtins.str:
         '''(experimental) The ARN of the application.
@@ -1379,7 +1379,7 @@ class _IApplicationProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "applicationArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationId")
     def application_id(self) -> builtins.str:
         '''(experimental) The ID of the application.
@@ -1426,7 +1426,7 @@ class IAttributeGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupArn")
     def attribute_group_arn(self) -> builtins.str:
         '''(experimental) The ARN of the attribute group.
@@ -1436,7 +1436,7 @@ class IAttributeGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupId")
     def attribute_group_id(self) -> builtins.str:
         '''(experimental) The ID of the attribute group.
@@ -1448,7 +1448,7 @@ class IAttributeGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IAttributeGroupProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''(experimental) A Service Catalog AppRegistry Attribute Group.
 
@@ -1457,7 +1457,7 @@ class _IAttributeGroupProxy(
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-servicecatalogappregistry.IAttributeGroup"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupArn")
     def attribute_group_arn(self) -> builtins.str:
         '''(experimental) The ARN of the attribute group.
@@ -1467,7 +1467,7 @@ class _IAttributeGroupProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attributeGroupArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupId")
     def attribute_group_id(self) -> builtins.str:
         '''(experimental) The ID of the attribute group.
@@ -1526,7 +1526,7 @@ class Application(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromApplicationArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromApplicationArn")
     @builtins.classmethod
     def from_application_arn(
         cls,
@@ -1590,7 +1590,7 @@ class Application(
             check_type(argname="argument resource_address", value=resource_address, expected_type=type_hints["resource_address"])
         return typing.cast(builtins.str, jsii.invoke(self, "generateUniqueHash", [resource_address]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationArn")
     def application_arn(self) -> builtins.str:
         '''(experimental) The ARN of the application.
@@ -1599,7 +1599,7 @@ class Application(
         '''
         return typing.cast(builtins.str, jsii.get(self, "applicationArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="applicationId")
     def application_id(self) -> builtins.str:
         '''(experimental) The ID of the application.
@@ -1668,7 +1668,7 @@ class AttributeGroup(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromAttributeGroupArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromAttributeGroupArn")
     @builtins.classmethod
     def from_attribute_group_arn(
         cls,
@@ -1691,7 +1691,7 @@ class AttributeGroup(
             check_type(argname="argument attribute_group_arn", value=attribute_group_arn, expected_type=type_hints["attribute_group_arn"])
         return typing.cast(IAttributeGroup, jsii.sinvoke(cls, "fromAttributeGroupArn", [scope, id, attribute_group_arn]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupArn")
     def attribute_group_arn(self) -> builtins.str:
         '''(experimental) The ARN of the attribute group.
@@ -1700,7 +1700,7 @@ class AttributeGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attributeGroupArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attributeGroupId")
     def attribute_group_id(self) -> builtins.str:
         '''(experimental) The ID of the attribute group.
